import sys
import ast
import numpy as np
from functools import reduce


def main():
    if sys.stdin.isatty():
        print("No input provided. Please pipe data into this script.", file=sys.stderr)
        sys.exit(1)

    if len(sys.argv) < 2:
        print("No lambda provided. Please provide a lambda as an argument. Example labmda a, c: a + c, just provide \"a+c\" where a is the accumulator and c is the current", file=sys.stderr)
        sys.exit(1)

    tree = ast.parse(f"lambda x: {sys.argv[1]}", mode='eval')
    f = eval(compile(tree, filename='<ast>', mode='eval'))
    for x in sorted(sys.stdin, key=lambda x: f(x[:-1])):
        print(x[:-1])



import matplotlib.pyplot as plt
import argparse, os
import numpy as np

def main(method=plt.plot):
    parser = argparse.ArgumentParser(description="Example of an optional string argument")
    parser.add_argument("--title", type=str, help="Title", default="")
    parser.add_argument("--xlabel", type=str, help="Horizontal axis label", default="")
    parser.add_argument("--ylabel", type=str, help="Vertical axis label", default="")
    parser.add_argument("--output", type=str, help="Output file", default="")
    parser.add_argument("--labels", type=str, help="Labels", default="")
    args = parser.parse_args()

    plt.figure()
    if "Y" in os.environ:
        y = int(os.environ["Y"].strip())
    else:
        y = None
    if "X" in os.environ:
        if os.environ["X"] == "":
            cols = None
        else:
            cols = [int(x.strip()) for x in os.environ["X"].split(",")]
    else:
        cols = None
    if args.labels == "":
        labels = None
    else:
        labels = [x.strip() for x in args.labels.split(",")]
    from .xy import data
    xs = cols if cols is not None else np.arange(data.shape[1])
    y = data[:, y] if y is not None else np.arange(data.shape[0])
    for i, col in enumerate(xs):
        method(y, data[:, col], label=labels[i] if (labels is not None) and i < len(labels) else None)
    if labels is not None:
        plt.legend(labels)
    if args.xlabel != "":
        plt.xlabel(args.xlabel)
    if args.ylabel != "":
        plt.ylabel(args.ylabel)
    if args.title != "":
        plt.title(args.title)
    if args.output == "":
        plt.show()
    else:
        plt.savefig(args.output)


if __name__ == "__main__":
    main()


from pathlib import Path
import sys

if Path(sys.argv[0]).name == "p2s":
    if len(sys.argv) == 2:
        from .flat import data
        import numpy as np
        format = sys.argv[1]
        while len(format) > 0:
            c = format[0]
            format = format[1:]
            if c == "c":
                print(f"Count: {np.count_nonzero(np.isnan(data) == False)}")
            elif c == "m":
                print(f"Mean: {np.nanmean(data)}")
            elif c == "s":
                print(f"Std: {np.nanstd(data)}")
            elif c == "q":
                c1 = format[0]
                c2 = format[1]
                assert c1.isdigit() and c2.isdigit()
                quantile_string = f"{c1}{c2}"
                quantile = int(quantile_string) / 100
                format = format[2:]
                print(f"Q{quantile_string}: {np.nanquantile(data, quantile)}")
            else:
                print(f"Unknown format modifier: {c}")
    else:
        from .stats import *


# for the entrypoint
def main():
    pass


import sys
import numpy as np


def main():
    if sys.stdin.isatty():
        print("No input provided. Please pipe data into this script.", file=sys.stderr)
        sys.exit(1)
    for x in sorted(set([x[:-1] for x in sys.stdin])):
        print(x)